@@ -1,5 +1,5 @@
 __all__ = ["pSock"]
-__version__ = "1.2.0"
+__version__ = "1.2.3"
 
 # -*- coding: utf-8 -*-
 
@@ -37,29 +37,6 @@ from . import _utils
 from ._utils import *
 import socket, threading, requests, json, bs4
 
-def gethostname():
-    return socket.gethostname()
-
-def getfdname():
-    return socket.getfqdn(socket.gethostname())
-
-def getproto(protocolname):
-    return socket.getprotobyname(protocolname)
-    
-def getservice(nameorport):
-    if type(nameorport) == str:
-        return socket.getservbyname(nameorport)
-    elif type(nameorport) == int:
-        return socket.getservbyport(nameorport)
-    else:
-        raise AttributeError(f"str or int expected, not {type(nameorport)}")
-
-def gethost(nameorip):
-    if str(nameorip).find("."):
-        socket.gethostbyaddr(nameorip)
-    else:
-        socket.gethostbyname(nameorip)
-
 # FAMILY ADDRESS
 
 LIST_OF_FAMILY_ADDRESS = ["AF_UNIX", "AF_INET", "AF_INET6", "AF_APPLETALK", "AF_BLUETOOTH", "AF_IPX", "AF_IRDA", "AF_LINK", "AF_SNA", "AF_UNSPEC"]
@@ -102,7 +79,7 @@ class LocalFunction:
             else:
                 return False
   
-class Web():
+class Web:
     
     def __init__(self):
         self.response = None
@@ -138,6 +115,13 @@ class Web():
     def getresponsetext(self, url):
         response = self.response = requests.get(url)
         return response.text
+    
+    @property
+    def responsemethod(self):
+        if self.response != None:
+            return self.response()
+        else:
+            raise OSError("Unable to convert in response class without execute getresponsetext().")
 
 class Net:
     def __init__(self, AddressFamily = AF_INET, Sock = SOCK_STREAM, Address = [None, None]):
@@ -243,4 +227,23 @@ class Net:
         if self.connection == False:
             raise OSError("Unable to close an unestablished connection.")
         self.sock.close()
-        self.connection = False
\ No newline at end of file
+        self.connection = False
+    
+    @property
+    def getactiveconnectionsdata(self):
+        if self.accepted:
+            return self.connectiondata, self.addressdata
+        else:
+            raise OSError("Unable to get active connection without accept().")
+    @property
+    def getactiveconnections(self):
+        if self.threadstarted:
+            return threading.active_count()
+        else:
+            raise OSError("Unable to get active connection without start().")
+    @property
+    def getaddr(self):
+        return [x[4][0] for x in socket.getaddrinfo(self.ip, self.port)] if self.netargs == True else None
+    @property
+    def gethost(self):
+        return socket.gethostbyaddr(self.ip) if self.netargs == True else None
\ No newline at end of file
